@@ -11,6 +11,7 @@ from djangocms_faq.models import (
 from .settings import (
     ANSWER_PLUGINS,
     ENABLE_API,
+    MAX_QUERY_LENGTH,
     SHOW_KEYWORDS_ANSWER,
     SHOW_KEYWORDS_QUESTION,
 )
@@ -64,8 +65,11 @@ if ENABLE_API:
             context.update({"show_keywords_question": SHOW_KEYWORDS_QUESTION})
             context.update({"show_keywords_answer": SHOW_KEYWORDS_ANSWER})
 
-            if "question" in context["request"].GET:
-                question = context["request"].GET["question"]
+            if (
+                "question" in context["request"].GET
+                and len(context["request"].GET["question"]) > 2
+            ):
+                question = context["request"].GET["question"][:MAX_QUERY_LENGTH]
 
                 if "search_in" in context["request"].GET:
                     search_in = context["request"].GET["search_in"]
