@@ -14,3 +14,9 @@ SHOW_KEYWORDS_ANSWER = getattr(settings, "DJANGOCMS_FAQ_SHOW_KEYWORDS_ANSWER", T
 
 ENABLE_FUZZY_SEARCH = getattr(settings, "DJANGOCMS_FAQ_ENABLE_FUZZY_SEARCH", False)
 FUZZY_SEARCH_PERCENTAGE = getattr(settings, "DJANGOCMS_FAQ_FUZZY_SEARCH_PERCENTAGE", 85)
+
+SEARCH_WORD_BY_WORD_KEYWORDS = getattr(
+    settings, "DJANGOCMS_FAQ_SEARCH_WORD_BY_WORD_KEYWORDS", False
+)
+
+MAX_QUERY_LENGTH = getattr(settings, "DJANGOCMS_FAQ_MAX_QUERY_LENGTH", 60)
