@@ -1,8 +1,8 @@
-from . import views
-
 from django.urls import path
 
+from . import views
+
 
 urlpatterns = [
-    path('', views.AnswerView, name="Answer Api"),
+    path("", views.AnswerView, name="Answer Api"),
 ]
